"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.scanCookies = scanCookies;
const detectorUtils_1 = require("../utils/functions/detectorUtils");
/**
 * Escanea las cookies proporcionadas y busca posibles problemas de seguridad.
 *
 * @param cookies - Un objeto que representa las cookies a escanear.
 * @param options - Opciones de escaneo.
 * @returns Un array de strings que contiene los problemas de seguridad encontrados.
 *
 * @remarks
 * Esta función escanea tanto las claves como los valores de las cookies proporcionadas.
 * Utiliza los detectores de seguridad configurados en las opciones para buscar posibles problemas.
 * Los problemas encontrados se agregan al array de issues y se devuelven al finalizar el escaneo.
 *
 * @author Andres Gutierrez Velez
 * @since 21/06/2024
 * @contact sr.willardkraft@gmail.com
 */
function scanCookies(cookies, options) {
    const issues = [];
    Object.entries(cookies).forEach(([key, value]) => {
        (0, detectorUtils_1.checkDetectors)(key, key, issues, options, true);
        (0, detectorUtils_1.checkDetectors)(value, key, issues, options);
    });
    return issues;
}
//# sourceMappingURL=scanCookies.js.map