import { ScanOptions } from '../../scan/interfaces/ITScanOptions';
/**
 * Comprueba diferentes detectores de seguridad en un valor dado y agrega los problemas detectados a una lista de problemas.
 * Los detectores incluyen la detección de sentencias SQL, inyección de SQL, XSS (Cross-Site Scripting) e inyección de scripts.
 *
 * @param value - El valor a comprobar.
 * @param key - La clave asociada al valor.
 * @param issues - La lista de problemas detectados.
 * @param options - Las opciones de escaneo.
 * @param isKey - Indica si el valor es una clave.
 * @returns void
 *
 * @remarks
 * Este método comprueba si el valor dado contiene sentencias SQL, inyección de SQL, XSS o inyección de scripts.
 * Si se detecta alguno de estos problemas, se agrega un mensaje de alerta a la lista de problemas.
 *
 * @example
 * checkDetectors("SELECT * FROM users", "query", issues, { detectSentences: true, detectReservedWords: true }, true);
 */
export declare function checkDetectors(value: any, key: string, issues: string[], options: ScanOptions, isKey?: boolean): void;
