const COMMAND_INJECTION_PATTERNS = [
  /\b(eval|exec|system|popen|passthru|shell_exec|proc_open)\b/i, // Funciones de ejecución de comandos
  /\b(sh|bash|perl|python|ruby|php|java|node|awk|find|xargs|wget|curl|netcat|nc|ftp|tftp|socat)\b/i, // Intérpretes de comandos y herramientas comunes
  /\b(rm|mv|cp|chmod|chown|chgrp)\b/i, // Comandos de manipulación de archivos
  /\b(ps|top|kill|pkill|killall)\b/i, // Comandos de administración de procesos
  /\b(ifconfig|ip a|ip addr|ip link|ip route)\b/i, // Comandos de configuración de red
  /\b(uname|id|whoami|hostname|dig|nslookup)\b/i, // Comandos de información del sistema
];

/**
 * Detects if there is a potential command injection vulnerability in a given string.
 *
 * @param input - The string to analyze.
 * @returns `true` if a potential command injection vulnerability is detected, otherwise `false`.
 *
 * @remarks
 * This function uses a series of regular expressions to look for common command injection patterns in the input string.
 * Patterns include shell operators, command substitution, backticks, and common command execution functions.
 *
 * @example
 * ```typescript
 * const input = "ls; cat /etc/passwd";
 * const isCommandInjection = detectCommandInjection(input);
 * console.log(isCommandInjection); // Output: true
 * ```
 *
 * @autor Andres Gutierrez Velez
 * @since 21/06/2024
 * @contact sr.willardkraft@gmail.com
 */
export function detectCommandInjection(input: string): boolean {
  return COMMAND_INJECTION_PATTERNS.some((pattern) => pattern.test(input));
}
